=========================
Viewing command-line help
=========================

To see a list of supported conda commands, in your terminal window or an Anaconda Prompt, run:

.. code-block:: bash

   conda --help

OR

.. code-block:: bash

   conda -h

To get help for a specific command, type the command name
followed by ``--help``.

EXAMPLE: To see help for the ``create`` command, in your terminal window or an Anaconda Prompt, run:

.. code-block:: bash

   conda create -h

.. note::
   You can see the same command help in :doc:`../../commands`.
